<!DOCTYPE style-sheet PUBLIC "-//James Clark//DTD DSSSL Style Sheet//EN" [
<!ENTITY  % ISOLat1     PUBLIC
            "ISO 8879:1986//ENTITIES Added Latin 1//EN">
          %ISOLat1;
<!ENTITY  % ISOLat2     PUBLIC
            "ISO 8879:1986//ENTITIES Added Latin 2//EN">
          %ISOLat2;
<!ENTITY  % ISOnum PUBLIC
            "ISO 8879:1986//ENTITIES Numeric and Special Graphic//EN">
          %ISOnum;
]>

<style-sheet>
<style-specification id="tieck"> 
    <!-- use="ca da de en es fi fr it ja nl no pl pt ro ru sv dbparam dblib"-->
<style-specification-body>

(declare-flow-object-class element
  "UNREGISTERED::James Clark//Flow Object Class::element")

(declare-flow-object-class empty-element
  "UNREGISTERED::James Clark//Flow Object Class::empty-element")

(declare-flow-object-class document-type
  "UNREGISTERED::James Clark//Flow Object Class::document-type")

(declare-flow-object-class processing-instruction
  "UNREGISTERED::James Clark//Flow Object Class::processing-instruction")

(declare-flow-object-class entity
  "UNREGISTERED::James Clark//Flow Object Class::entity")

(declare-flow-object-class entity-ref
  "UNREGISTERED::James Clark//Flow Object Class::entity-ref")

(declare-flow-object-class formatting-instruction
  "UNREGISTERED::James Clark//Flow Object Class::formatting-instruction")

(declare-characteristic preserve-sdata?
  "UNREGISTERED::James Clark//Characteristic::preserve-sdata?" #t)

(define debug
  (external-procedure "UNREGISTERED::James Clark//Procedure::debug"))

(define read-entity
  (external-procedure "UNREGISTERED::James Clark//Procedure::read-entity"))

(define all-element-number
  (external-procedure "UNREGISTERED::James Clark//Procedure::all-element-number"))

(define chunk #f)

; Creates an HTML element in Jade given a start tag (and optional
; attribute)

; You may also supply content, such as the rows of a table.

(define (make-html-element element #!rest content)
    (sosofo-append
     (make formatting-instruction
           data:(string-append "<" element ">"))
     (apply sosofo-append content)
     (make formatting-instruction
           data:(string-append "</" (first-word element) ">" ))))

; Finds the first word in a string. Used to find the GI
; in a GI and attribute string
(define first-word
  (lambda (str)
    (letrec ((find-space
            (lambda (str pos)
              (if (or
                        (equal? (string-length str) pos)
                        (equal? (string-ref str pos) #\space))

                  pos
                  (find-space str (+ pos 1))))))
      (substring str 0 (find-space str 0)))))

(define (make-html-meta name-val content-val #!optional name)
  (make empty-element gi: "meta"
	attributes: (list (list (or name "name") name-val)
			  (list "content" content-val))
	;;(empty-sosofo)
	))

<!-- Based on:                                                      -->
<!-- From: Brandon Ibach <bibach@infomansol.com>       	       	    -->
<!-- Subject: Re: Example of multiple html files from one xml file  -->
<!-- To: dssslist@mulberrytech.com				    -->
<!-- Date: Mon, 30 Oct 2000 12:24:46 -0600			    -->
<!-- Reply-To: dssslist@mulberrytech.com			    -->
<!-- Message-ID: <20001030122446.C4648@unix.netstream.net>	    -->

(define (file-name nd)
  (string-append
   (or (attribute-string "ID" nd)
       (let* ((nds (select-elements
		    (descendants
		     (node-property 'document-element
				    (node-property 'grove-root nd)))
		    (gi nd)))
	      (num (let loop ((n nds) (r 1))
		     (if (node-list-empty? n) 0
			 (if (node-list=? (node-list-first n) nd) r
			     (loop (node-list-rest n) (+ r 1)))))))
	 (string-append (gi nd) (number->string num))))
   ".html"))

(define (make-file fname ssf)
  (make entity system-id: fname
	(make document-type name: "html"
	      public-id: "-//W3C//DTD HTML 4.0//EN")
	(make element gi: "html"
	      (make element gi: "head"
		    (make element gi: "title"
			  (literal (string-append "Ludwig Tieck: Franz Sternbald's Wanderungen (" fname ")")))
		    ;; (make element gi: "title" (empty-sosofo))
		    (make-html-meta "Content-Type"
				  "text/html; charset=iso-8859-1" "http-equiv" ))
	      (make element gi: "body" ssf))))

(define (subdocrule)
  (let* ((f (file-name (current-node)))
	 (ident (substring f 0 (- (string-length f) 5))))
    (sosofo-append
     (make-file f
		(make sequence
		  (make element gi: "a"
			attributes: (list (list "href" (string-append
							"koepke.html#toc-" ident)))
			(literal "[ Zurck zum bergeordneten Inhaltsverzeichnis ]"))
		  (make element gi: "H2" (literal
					  (string-append "Inhaltsverzeichnis (" ident "):")))
		  (make element gi: "ul"
			(with-mode toc (process-matching-children 'div)))
		  (make element gi: "a"
			attributes: (list (list "href" (string-append
							"koepke.html#toc-" ident)))
			(literal "[ Zurck zum bergeordneten Inhaltsverzeichnis ]"))
		  (make empty-element gi: "hr")
		  (process-children)
		  (make element gi: "a"
			attributes: (list (list "href" (string-append
							"koepke.html#toc-" ident)))
			(literal "[ Zurck zum bergeordneten Inhaltsverzeichnis ]"))))
     ;; ;; write simple index
     ;; (make sequence
     ;;   (make element gi: "a" attributes: (list (list "href" f)
     ;; 					       (list "name" ident))
     ;; 	     (literal ident))
     ;;   (make empty-element gi: "br"))
     )))

<!-- end of Message-ID: <20001030122446.C4648@unix.netstream.net>	    -->

(element tei.2
  (make sequence
    (make document-type name: "html"
          public-id: "-//W3C//DTD HTML 4.0//EN")
    (make element gi: "html"
          (make sequence
            (make element gi: "head"
                  ;; (empty-sosofo)
                  (make element gi: "title"
                        (literal "Ludwig Tieck: Franz Sternbald's Wanderungen"))
                  (make-html-meta "Content-Type"
				  "text/html; charset=iso-8859-1" "http-equiv" )
		  (make-html-meta "DC.Title" "Franz Sternbald's Wanderungen" )
		  (make-html-meta "DC.Author" (string-append "Ludwig Tieck"))
		  ;; (make-html-meta "DC.Author" (string-append "Rudolf K&amp;ouml;pke"))
		  (make-html-meta "DC.Language" "(SCHEME=iso639) de")
		  (make-html-meta "DC.Creator" "Karl Eichwalder")
		  (make-html-meta "DC.Creator.Address" "keichwa@gmx.net")
                  (make-html-meta "keywords"
				  (string-append "Ludwig Tieck, Franz Sternbald's Wanderungen, Text, sgml, Roman, Romantik"))
                  )
            ;; (small-horiz-rule)
            (make element gi: "BODY"
            ;;       ;; (empty-sosofo)
            ;;       )
          ;; (process-node-list 'teiheader)
                  (make empty-element gi: "HR")
                  (process-matching-children "teiheader")
                  (process-matching-children "text"))
          ;; (process-children)
          ))))

(define (make-div-attributes file)
  (list (list "CLASS" "link")
	(list "href" (string-append file "#"
				    (attribute-string "id")))
	(list "name" (string-append "toc-"
				    (attribute-string "id")))))
(mode toc 
  (element (body div)
    (let ((filename (if chunk
			(file-name (current-node)) "")))
      (make element gi: "li"
	    (make element gi: "a"
		  attributes: (make-div-attributes filename)
		  (process-first-descendant 'head)
		  (make element gi: "ul"
			(process-matching-children 'div))))))
  (element (body div div)
    (let ((filename (if chunk
			(file-name (parent (current-node))) "")))
      (make element gi: "li"
	    (make element gi: "a"
		  attributes: (make-div-attributes filename)
		  (process-first-descendant 'head)
		  (if (select-elements (children (current-node)) "div")
		      (make element gi: "ul"
			    (process-matching-children 'div))
		      '()))
		  )))
  (element (body div div div)
    (let ((filename (if chunk
			(file-name (parent (parent (current-node)))) "")))
      (make element gi: "li"
	    (make element gi: "a"
		  attributes: (make-div-attributes filename)
		  (process-first-descendant 'head)
		  (make element gi: "ul"
			(process-matching-children 'div))))))
  (element (body div div div div)
    (let ((filename (if chunk
			(file-name (parent (parent (parent (current-node))))) "")))
      (make element gi: "li"
	    (make element gi: "a"
		  attributes: (make-div-attributes filename)
		  (process-first-descendant 'head)
		  (make element gi: "ul"
			(process-matching-children 'div))))))
  (element head
          (process-children))
  (element title
    (process-children-trim)))

(element (teiheader filedesc titlestmt title)
  (make-html-element "H1"
                     (process-children)))

(element editionstmt (make-html-element "SPAN"
                                       (make element gi: "h3"
                                             (literal "(editionstmt)"))
                                          (process-children)))
(element publicationstmt (make-html-element "SPAN"
                                       (make element gi: "h3"
                                             (literal "(publicationstmt)"))
                                          (process-children)))
(element notesstmt (make-html-element "SPAN"
                                       (make element gi: "h3"
                                             (literal "(notesstmt)"))
                                          (process-children)))
(element sourcedesc (make-html-element "SPAN"
                                       (make element gi: "h3"
                                             (literal "Beschreibung der
Quelle (sourcedesc)"))
                                          (process-children)))
(element normalization (make-html-element "SPAN"
                                          (make element gi: "h3"
                                                (literal "Normalisierung
(normalization)"))
                                          (process-children)))

(element encodingdesc (make-html-element "SPAN"
                                          (make element gi: "h3"
                                                (literal "(encodingdesc)"))
                                          (process-children)))

(element resp (make-html-element "SPAN" (process-children)
                                 (literal "\space")))
(element name (make-html-element "SPAN" (process-children)))
;; (element text (make-html-element "HR"
;;                                  (process-children)))

(element teiheader
  (make sequence (process-children)))
;;         (make element
;;           gi: "ul"
;;           (with-mode make-toc-links
;;             (process-node-list (book-node))))))

(define (book-node)
  (cond ((equal? (gi) "text") (current-node))
	(#t (ancestor "text"))))

(element text
  (make element gi: "div"
        attributes: (list (list "CLASS" (gi)))
        (process-matching-children "body")
))

(element body ;; (make-html-element "BODY"
  (make sequence
    (make empty-element gi: "HR")
                  (make sequence
                    ;; (process-matching-children 'div)
                    (make element
                      gi: "A"
                      attributes: (list (list "name" "toc"))
                      (empty-sosofo))
                    (make element gi: "H1" (literal "Inhaltsverzeichnis:"))

                    ;; (make sequence
                    (make element gi: "ul"
                          (with-mode toc (process-matching-children 'div)))
                    (make empty-element gi: "HR")
                    (process-children))))

;; (element div (make-html-element "DIV"
;;                                 (process-children)))

(element (body div)
  (if chunk
      (subdocrule)
      (make sequence
	(make-anchor)
	(process-children)
	)))

(element (body div div)
  (make sequence
    (make-anchor)
    (process-children)
    (make empty-element gi: "hr")
    ))

(element div
  (make sequence
    (make-anchor)
    (process-children)))

(define (make-anchor)
  (if (id)
      (make element
	gi: "A"
	attributes: (list (list "name" (id)))
	(literal ""))
      (empty-sosofo)))

(mode make-toc-links
  (element (DIV)
    (make sequence
      (make empty-element
	gi: "LI")
      (let ((title-text (with-mode extract-title-text
			  (process-first-descendant "TITLE"))))
	(make element
	  gi: "A"
	  attributes: (list (list "href" (string-append
                                          (link-file-name (current-node))
                                          "#"
                                          (gi)
                                          (number->string (all-element-number (current-node))))))
	  title-text))
      (let ((refentries (select-elements (children (current-node)) "REFENTRY")))
	(if (node-list-empty? refentries)
	    (empty-sosofo)
	    (make element
	      gi: "ul"
	      (with-mode make-toc-links (process-node-list refentries)))))))
  (default
    (empty-sosofo)))

(define (link-file-name target)
  "")

(mode extract-title-text
  (element (TITLE)
    (process-children)))

(define (back-to-toc1)
  (make element gi: "a"
	attributes: (list (list "href" "#toc"))
	(literal " [ Zurck zum Inhaltsverzeichnis ]")))

(define (back-to-toc)
  (make element gi: "a"
	attributes: (list (list "href"
				(string-append "#toc-"
					       (attribute-string "id" (ancestor "div")))))
	(literal " [ Zurck zum Inhaltsverzeichnis ]")))


(element head (make element gi: "H2"
		    (process-children-trim)
		    (back-to-toc)))

(element (div div head)
  (make element gi: "H3"
	(process-children-trim)
	(back-to-toc)))

(element p (make element gi: "P"
                              (process-children)))
(element l (make element gi: "P"
                 attributes: '(("align" "center"))
                              (process-children)))
(element note (make-html-element "P"
                              (process-children)))

(element pb (literal "[S." (attribute-string "n") "]"))

(element (body div head title)
  (make sequence
    (process-children-trim)
    (make empty-element gi: "br")))

</style-specification-body>
</style-specification>

</style-sheet>
